@@ -1,13 +1,13 @@
 """ Common tools """
 
-__version__ = "2.0.0"
+__version__ = "2.2.0"
 
 from .config import Config, parse_config  # noqa
 from .errors import Error, InvalidConfig  # noqa
 from .executor import Task, run_sequence, ExecutorFailed  # noqa
 from .groups import GroupList, Group  # noqa
 from .groups import GroupNotFound, UnknownElement as UnknownGroupElement  # noqa
-from .repo import Repo, Remote, Copy  # noqa
+from .repo import Repo, Remote, Copy, Link, FileSystemOperation  # noqa
 from .manifest import Manifest  # noqa
 from .manifest import load as load_manifest  # noqa
 from .workspace import Workspace  # noqa
