@@ -4,15 +4,15 @@ import argparse
 
 import cli_ui as ui
 import tsrc.cli
-from tsrc.workspace.local_manifest import LocalManifest
 
 
 def main(args: argparse.Namespace) -> None:
     workspace = tsrc.cli.get_workspace(args)
     manifest_path = args.manifest_path
-    ui.info_1("Applying manifest from", args.manifest_path)
 
-    workspace.local_manifest = LocalManifest(manifest_path.parent)
+    ui.info_1("Applying manifest from", args.manifest_path)
+    manifest = tsrc.manifest.load(manifest_path)
+    workspace.repos = tsrc.cli.repos_from_config(manifest, workspace.config)
     workspace.clone_missing()
     workspace.set_remotes()
-    workspace.copy_files()
+    workspace.perform_filesystem_operations()
