@@ -6,6 +6,7 @@ from path import Path
 import cli_ui as ui
 
 import tsrc
+from tsrc.cli import repos_from_config
 from tsrc.workspace import Workspace
 from tsrc.workspace.config import WorkspaceConfig
 
@@ -26,14 +27,17 @@ def main(args: argparse.Namespace) -> None:
         clone_all_repos=args.clone_all_repos,
         repo_groups=args.groups,
         shallow_clones=args.shallow,
+        singular_remote=args.remote,
     )
 
     workspace_config.save_to_file(cfg_path)
 
     workspace = Workspace(workspace_path)
     workspace.update_manifest()
+    manifest = workspace.get_manifest()
+    workspace.repos = repos_from_config(manifest, workspace_config)
     workspace.clone_missing()
     workspace.set_remotes()
-    workspace.copy_files()
+    workspace.perform_filesystem_operations()
     ui.info_2("Workspace initialized")
     ui.info_2("Configuration written in", ui.bold, workspace.cfg_path)
