@@ -105,6 +105,11 @@ def main(args: ArgsList = None) -> None:
     main_impl(args=args)
 
 
+def add_group_options(parser: argparse.ArgumentParser) -> None:
+    parser.add_argument("-g", "--group", "--groups", nargs="+", dest="groups")
+    parser.add_argument("--all-cloned", action="store_true", dest="all_cloned")
+
+
 def main_impl(args: ArgsList = None) -> None:
     parser = argparse.ArgumentParser(prog="tsrc")
     parser.add_argument(
@@ -122,15 +127,9 @@ def main_impl(args: ArgsList = None) -> None:
     subparsers.add_parser("version")
 
     foreach_parser = add_workspace_subparser(subparsers, "foreach")
+    add_group_options(foreach_parser)
     foreach_parser.add_argument("cmd", nargs="*")
     foreach_parser.add_argument("-c", dest="shell", action="store_true")
-    foreach_parser.add_argument("-g", "--group", action="append", dest="groups")
-    foreach_parser.add_argument(
-        "--groups-from-config",
-        action="store_true",
-        help="Use groups from the workspace configuration",
-        default=False,
-    )
     foreach_parser.epilog = textwrap.dedent(
         """\
     Usage:
@@ -144,9 +143,9 @@ def main_impl(args: ArgsList = None) -> None:
     foreach_parser.formatter_class = argparse.RawDescriptionHelpFormatter
 
     init_parser = add_workspace_subparser(subparsers, "init")
+    add_group_options(init_parser)
     init_parser.add_argument("url")
     init_parser.add_argument("-b", "--branch")
-    init_parser.add_argument("-g", "--group", "--groups", nargs="+", dest="groups")
     init_parser.add_argument(
         "--clone-all-repos",
         action="store_true",
@@ -156,16 +155,25 @@ def main_impl(args: ArgsList = None) -> None:
     init_parser.add_argument(
         "-s", "--shallow", action="store_true", dest="shallow", default=False
     )
+    init_parser.add_argument(
+        "-r",
+        "--remote",
+        dest="remote",
+        help="Use only the remote with this name to clone repositories",
+    )
     init_parser.set_defaults(branch="master")
 
     log_parser = add_workspace_subparser(subparsers, "log")
+    add_group_options(log_parser)
     log_parser.add_argument("--from", required=True, dest="from_", metavar="FROM")
     log_parser.add_argument("--to")
     log_parser.set_defaults(to="HEAD")
 
-    add_workspace_subparser(subparsers, "status")
+    status_parser = add_workspace_subparser(subparsers, "status")
+    add_group_options(status_parser)
 
     sync_parser = add_workspace_subparser(subparsers, "sync")
+    add_group_options(sync_parser)
     sync_parser.add_argument("--force", action="store_true")
 
     apply_manifest = add_workspace_subparser(subparsers, "apply-manifest")
@@ -178,7 +186,7 @@ def main_impl(args: ArgsList = None) -> None:
     if not command:
         parser.print_help()
         sys.exit(1)
-    module = importlib.import_module("tsrc.cli.%s" % command.replace("-", "_"))
+    module = importlib.import_module("tsrc.cli." + command.replace("-", "_"))
     if command == "foreach":
         fix_cmd_args_for_foreach(args_ns, foreach_parser)
 
