@@ -87,12 +87,12 @@ def describe_position(git_status: tsrc.git.Status) -> List[ui.Token]:
     if git_status.ahead != 0:
         up = ui.Symbol("↑", "+")
         n_commits = commit_string(git_status.ahead)
-        ahead_desc = "{}{} {}".format(up.as_string, git_status.ahead, n_commits)
+        ahead_desc = f"{up.as_string}{git_status.ahead} {n_commits}"
         res += [ui.blue, ahead_desc, ui.reset]
     if git_status.behind != 0:
         down = ui.Symbol("↓", "-")
         n_commits = commit_string(git_status.behind)
-        behind_desc = "{}{} {}".format(down.as_string, git_status.behind, n_commits)
+        behind_desc = f"{down.as_string}{git_status.behind} {n_commits}"
         res += [ui.blue, behind_desc, ui.reset]
     return res
 
@@ -117,14 +117,14 @@ class StatusCollector(tsrc.Task[tsrc.Repo]):
         self.num_repos = 0
 
     def display_item(self, repo: tsrc.Repo) -> str:
-        return repo.src
+        return repo.dest
 
     def process(self, index: int, total: int, repo: tsrc.Repo) -> None:
-        ui.info_count(index, total, repo.src, end="\r")
-        full_path = self.workspace.root_path / repo.src
+        ui.info_count(index, total, repo.dest, end="\r")
+        full_path = self.workspace.root_path / repo.dest
 
         if not full_path.exists():
-            self.statuses[repo.src] = tsrc.errors.MissingRepo(repo.src)
+            self.statuses[repo.dest] = tsrc.errors.MissingRepo(repo.dest)
             return
 
         try:
@@ -132,13 +132,13 @@ class StatusCollector(tsrc.Task[tsrc.Repo]):
             manifest_status = ManifestStatus(repo, manifest=self.manifest)
             manifest_status.update(git_status)
             status = Status(git=git_status, manifest=manifest_status)
-            self.statuses[repo.src] = status
+            self.statuses[repo.dest] = status
         except Exception as e:
-            self.statuses[repo.src] = e
+            self.statuses[repo.dest] = e
         erase_last_line()
 
     def on_start(self, num_items: int) -> None:
-        ui.info_1("Collecting statuses of %d repos" % num_items)
+        ui.info_1(f"Collecting statuses of {num_items} repo(s)")
         self.num_repos = num_items
 
     def on_success(self) -> None:
@@ -147,14 +147,14 @@ class StatusCollector(tsrc.Task[tsrc.Repo]):
             ui.info_2("Workspace is empty")
             return
         ui.info_2("Workspace status:")
-        max_src = max(len(x) for x in self.statuses.keys())
-        for src, status in self.statuses.items():
-            message = [ui.green, "*", ui.reset, src.ljust(max_src)]
+        max_dest = max(len(x) for x in self.statuses.keys())
+        for dest, status in self.statuses.items():
+            message = [ui.green, "*", ui.reset, dest.ljust(max_dest)]
             message += describe_status(status)
             ui.info(*message)
 
 
 def main(args: argparse.Namespace) -> None:
-    workspace = tsrc.cli.get_workspace(args)
+    workspace = tsrc.cli.get_workspace_with_repos(args)
     status_collector = StatusCollector(workspace)
-    tsrc.run_sequence(workspace.get_repos(), status_collector)
+    tsrc.run_sequence(workspace.repos, status_collector)
