@@ -1,3 +1,5 @@
+from typing import Optional
+
 import textwrap
 
 from path import Path
@@ -9,9 +11,16 @@ import tsrc.executor
 
 
 class Cloner(tsrc.executor.Task[tsrc.Repo]):
-    def __init__(self, workspace_path: Path, *, shallow: bool = False) -> None:
+    def __init__(
+        self,
+        workspace_path: Path,
+        *,
+        shallow: bool = False,
+        remote_name: Optional[str] = None,
+    ) -> None:
         self.workspace_path = workspace_path
         self.shallow = shallow
+        self.remote_name = remote_name
 
     def on_start(self, *, num_items: int) -> None:
         ui.info_2("Cloning missing repos")
@@ -20,26 +29,37 @@ class Cloner(tsrc.executor.Task[tsrc.Repo]):
         ui.error("Failed to clone missing repos")
 
     def display_item(self, repo: tsrc.Repo) -> str:
-        return repo.src
+        return repo.dest
 
     def check_shallow_with_sha1(self, repo: tsrc.Repo) -> None:
         if not repo.sha1:
             return
         if self.shallow:
             message = textwrap.dedent(
-                "Cannot use --shallow with a fixed sha1 ({repo.sha1})\n"
+                f"Cannot use --shallow with a fixed sha1 ({repo.sha1})\n"
                 "Consider using a tag instead"
             )
-            message = message.format(repo=repo)
             raise tsrc.Error(message)
 
+    def _choose_remote(self, repo: tsrc.Repo) -> tsrc.Remote:
+        if self.remote_name:
+            for remote in repo.remotes:
+                if remote.name == self.remote_name:
+                    return remote
+            message = (
+                f"Remote '{self.remote_name}' not found for repository '{repo.dest}'"
+            )
+            raise tsrc.Error(message)
+
+        return repo.remotes[0]
+
     def clone_repo(self, repo: tsrc.Repo) -> None:
-        repo_path = self.workspace_path / repo.src
+        repo_path = self.workspace_path / repo.dest
         parent, name = repo_path.splitpath()
         parent.makedirs_p()
-        first_remote = repo.remotes[0]
-        remote_name = first_remote.name
-        remote_url = first_remote.url
+        remote = self._choose_remote(repo)
+        remote_name = remote.name
+        remote_url = remote.url
         clone_args = ["clone", "--origin", remote_name, remote_url]
         ref = None
         if repo.tag:
@@ -57,17 +77,17 @@ class Cloner(tsrc.executor.Task[tsrc.Repo]):
             raise tsrc.Error("Cloning failed")
 
     def reset_repo(self, repo: tsrc.Repo) -> None:
-        repo_path = self.workspace_path / repo.src
+        repo_path = self.workspace_path / repo.dest
         ref = repo.sha1
         if ref:
-            ui.info_2("Resetting", repo.src, "to", ref)
+            ui.info_2("Resetting", repo.dest, "to", ref)
             try:
                 tsrc.git.run(repo_path, "reset", "--hard", ref)
             except tsrc.Error:
                 raise tsrc.Error("Resetting to", ref, "failed")
 
     def process(self, index: int, count: int, repo: tsrc.Repo) -> None:
-        ui.info_count(index, count, repo.src)
+        ui.info_count(index, count, repo.dest)
         self.check_shallow_with_sha1(repo)
         self.clone_repo(repo)
         self.reset_repo(repo)
