@@ -6,19 +6,17 @@ import ruamel.yaml
 
 @attr.s
 class WorkspaceConfig:
-    """ Persistent configuration of the workspace
+    """ Persistent configuration of the workspace """
 
-    """
-
-    # Note: always use a default value so the ctor only
-    # takes named arguments
-    manifest_url = attr.ib(default=None)  # type: str
-    manifest_branch = attr.ib(default=None)  # type: str
+    manifest_url = attr.ib()  # type: str
+    manifest_branch = attr.ib()  # type: str
+    repo_groups = attr.ib()  # type: List[str]
 
     shallow_clones = attr.ib(default=False)  # type: bool
-    repo_groups = attr.ib(default=[])  # type: List[str]
     clone_all_repos = attr.ib(default=False)  # type: bool
 
+    singular_remote = attr.ib(default=None)  # type: Optional[str]
+
     @manifest_url.validator
     def check(self, attribute: str, value: Optional[str] = None) -> None:
         if value is None:
@@ -27,7 +25,7 @@ class WorkspaceConfig:
     @classmethod
     def from_file(cls, cfg_path: Path) -> "WorkspaceConfig":
         yaml = ruamel.yaml.YAML(typ="rt")
-        parsed = yaml.load(cfg_path.text())
+        parsed = yaml.load(cfg_path.read_text())
         return cls(**parsed)
 
     def save_to_file(self, cfg_path: Path) -> None:
