@@ -1,4 +1,4 @@
-from typing import List, Tuple  # noqa
+from typing import List, Optional, Tuple  # noqa
 import attr
 from path import Path
 import cli_ui as ui
@@ -14,16 +14,23 @@ class BadBranches(tsrc.Error):
 
 @attr.s(frozen=True)
 class RepoAtIncorrectBranchDescription:
-    src = attr.ib()  # type: str
+    dest = attr.ib()  # type: str
     actual = attr.ib()  # type: str
     expected = attr.ib()  # type: str
 
 
 class Syncer(tsrc.executor.Task[tsrc.Repo]):
-    def __init__(self, workspace_path: Path, *, force: bool = False) -> None:
+    def __init__(
+        self,
+        workspace_path: Path,
+        *,
+        force: bool = False,
+        remote_name: Optional[str] = None,
+    ) -> None:
         self.workspace_path = workspace_path
         self.bad_branches = []  # type: List[RepoAtIncorrectBranchDescription]
         self.force = force
+        self.remote_name = remote_name
 
     def on_start(self, *, num_items: int) -> None:
         ui.info_1("Synchronizing workspace")
@@ -32,11 +39,11 @@ class Syncer(tsrc.executor.Task[tsrc.Repo]):
         ui.error("Failed to synchronize workspace")
 
     def display_item(self, repo: tsrc.Repo) -> str:
-        return repo.src
+        return repo.dest
 
     def process(self, index: int, count: int, repo: tsrc.Repo) -> None:
-        ui.info_count(index, count, repo.src)
-        repo_path = self.workspace_path / repo.src
+        ui.info_count(index, count, repo.dest)
+        repo_path = self.workspace_path / repo.dest
         self.fetch(repo)
         ref = None
 
@@ -61,13 +68,23 @@ class Syncer(tsrc.executor.Task[tsrc.Repo]):
         if current_branch and current_branch != repo.branch:
             self.bad_branches.append(
                 RepoAtIncorrectBranchDescription(
-                    src=repo.src, actual=current_branch, expected=repo.branch
+                    dest=repo.dest, actual=current_branch, expected=repo.branch
                 )
             )
 
+    def _pick_remotes(self, repo: tsrc.Repo) -> List[tsrc.Remote]:
+        if self.remote_name:
+            for remote in repo.remotes:
+                if remote.name == self.remote_name:
+                    return [remote]
+            message = f"Remote {self.remote_name} not found for repository {repo.dest}"
+            raise tsrc.Error(message)
+
+        return repo.remotes
+
     def fetch(self, repo: tsrc.Repo) -> None:
-        repo_path = self.workspace_path / repo.src
-        for remote in repo.remotes:
+        repo_path = self.workspace_path / repo.dest
+        for remote in self._pick_remotes(repo):
             try:
                 ui.info_2("Fetching", remote.name)
                 cmd = ["fetch", "--tags", "--prune", remote.name]
@@ -75,14 +92,14 @@ class Syncer(tsrc.executor.Task[tsrc.Repo]):
                     cmd.append("--force")
                 tsrc.git.run(repo_path, *cmd)
             except tsrc.Error:
-                raise tsrc.Error("fetch from %s failed" % remote.name)
+                raise tsrc.Error(f"fetch from '{remote.name}' failed")
 
     @staticmethod
     def sync_repo_to_ref(repo_path: Path, ref: str) -> None:
         ui.info_2("Resetting to", ref)
         status = tsrc.git.get_status(repo_path)
         if status.dirty:
-            raise tsrc.Error("%s is dirty, skipping" % repo_path)
+            raise tsrc.Error(f"{repo_path} is dirty, skipping")
         try:
             tsrc.git.run(repo_path, "reset", "--hard", ref)
         except tsrc.Error:
@@ -102,7 +119,7 @@ class Syncer(tsrc.executor.Task[tsrc.Repo]):
         ui.error("Some projects were not on the correct branch")
         headers = ("project", "actual", "expected")
         data = [
-            ((ui.bold, x.src), (ui.red, x.actual), (ui.green, x.expected))
+            ((ui.bold, x.dest), (ui.red, x.actual), (ui.green, x.expected))
             for x in self.bad_branches
         ]
         ui.info_table(data, headers=headers)
